==> openshift-model-4.13.0-sources.jar: annotations/io/fabric8/openshift/api/model/GitHubIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface GitHubIdentityProviderFluent<A extends GitHubIdentityProviderFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildCa instead.
 * @return The buildable object.
 */
@Deprecated public ConfigMapNameReference getCa();
    public ConfigMapNameReference buildCa();
    public A withCa(ConfigMapNameReference ca);
    public Boolean hasCa();
    public A withNewCa(String name);
    public GitHubIdentityProviderFluent.CaNested<A> withNewCa();
    public GitHubIdentityProviderFluent.CaNested<A> withNewCaLike(ConfigMapNameReference item);
    public GitHubIdentityProviderFluent.CaNested<A> editCa();
    public GitHubIdentityProviderFluent.CaNested<A> editOrNewCa();
    public GitHubIdentityProviderFluent.CaNested<A> editOrNewCaLike(ConfigMapNameReference item);
    public String getClientID();
    public A withClientID(String clientID);
    public Boolean hasClientID();
    public A withNewClientID(String arg1);
    public A withNewClientID(StringBuilder arg1);
    public A withNewClientID(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildClientSecret instead.
 * @return The buildable object.
 */
@Deprecated public SecretNameReference getClientSecret();
    public SecretNameReference buildClientSecret();
    public A withClientSecret(SecretNameReference clientSecret);
    public Boolean hasClientSecret();
    public A withNewClientSecret(String name);
    public GitHubIdentityProviderFluent.ClientSecretNested<A> withNewClientSecret();
    public GitHubIdentityProviderFluent.ClientSecretNested<A> withNewClientSecretLike(SecretNameReference item);
    public GitHubIdentityProviderFluent.ClientSecretNested<A> editClientSecret();
    public GitHubIdentityProviderFluent.ClientSecretNested<A> editOrNewClientSecret();
    public GitHubIdentityProviderFluent.ClientSecretNested<A> editOrNewClientSecretLike(SecretNameReference item);
    public String getHostname();
    public A withHostname(String hostname);
    public Boolean hasHostname();
    public A withNewHostname(String arg1);
    public A withNewHostname(StringBuilder arg1);
    public A withNewHostname(StringBuffer arg1);
    public A addToOrganizations(int index,String item);
    public A setToOrganizations(int index,String item);
    public A addToOrganizations(String... items);
    public A addAllToOrganizations(Collection<String> items);
    public A removeFromOrganizations(String... items);
    public A removeAllFromOrganizations(Collection<String> items);
    public List<String> getOrganizations();
    public String getOrganization(int index);
    public String getFirstOrganization();
    public String getLastOrganization();
    public String getMatchingOrganization(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingOrganization(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withOrganizations(List<String> organizations);
    public A withOrganizations(String... organizations);
    public Boolean hasOrganizations();
    public A addNewOrganization(String arg1);
    public A addNewOrganization(StringBuilder arg1);
    public A addNewOrganization(StringBuffer arg1);
    public A addToTeams(int index,String item);
    public A setToTeams(int index,String item);
    public A addToTeams(String... items);
    public A addAllToTeams(Collection<String> items);
    public A removeFromTeams(String... items);
    public A removeAllFromTeams(Collection<String> items);
    public List<String> getTeams();
    public String getTeam(int index);
    public String getFirstTeam();
    public String getLastTeam();
    public String getMatchingTeam(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingTeam(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withTeams(List<String> teams);
    public A withTeams(String... teams);
    public Boolean hasTeams();
    public A addNewTeam(String arg1);
    public A addNewTeam(StringBuilder arg1);
    public A addNewTeam(StringBuffer arg1);
    public interface CaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConfigMapNameReferenceFluent<GitHubIdentityProviderFluent.CaNested<N>> {

        public N and();
        public N endCa();    }


    public interface ClientSecretNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SecretNameReferenceFluent<GitHubIdentityProviderFluent.ClientSecretNested<N>> {

        public N and();
        public N endClientSecret();    }


}

==> openshift-model-5.0.0-sources.jar: annotations/io/fabric8/openshift/api/model/GitHubIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface GitHubIdentityProviderFluent<A extends GitHubIdentityProviderFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildCa instead.
 * @return The buildable object.
 */
@Deprecated public ConfigMapNameReference getCa();
    public ConfigMapNameReference buildCa();
    public A withCa(ConfigMapNameReference ca);
    public Boolean hasCa();
    public A withNewCa(String name);
    public GitHubIdentityProviderFluent.CaNested<A> withNewCa();
    public GitHubIdentityProviderFluent.CaNested<A> withNewCaLike(ConfigMapNameReference item);
    public GitHubIdentityProviderFluent.CaNested<A> editCa();
    public GitHubIdentityProviderFluent.CaNested<A> editOrNewCa();
    public GitHubIdentityProviderFluent.CaNested<A> editOrNewCaLike(ConfigMapNameReference item);
    public String getClientID();
    public A withClientID(String clientID);
    public Boolean hasClientID();
    public A withNewClientID(String arg1);
    public A withNewClientID(StringBuilder arg1);
    public A withNewClientID(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildClientSecret instead.
 * @return The buildable object.
 */
@Deprecated public SecretNameReference getClientSecret();
    public SecretNameReference buildClientSecret();
    public A withClientSecret(SecretNameReference clientSecret);
    public Boolean hasClientSecret();
    public A withNewClientSecret(String name);
    public GitHubIdentityProviderFluent.ClientSecretNested<A> withNewClientSecret();
    public GitHubIdentityProviderFluent.ClientSecretNested<A> withNewClientSecretLike(SecretNameReference item);
    public GitHubIdentityProviderFluent.ClientSecretNested<A> editClientSecret();
    public GitHubIdentityProviderFluent.ClientSecretNested<A> editOrNewClientSecret();
    public GitHubIdentityProviderFluent.ClientSecretNested<A> editOrNewClientSecretLike(SecretNameReference item);
    public String getHostname();
    public A withHostname(String hostname);
    public Boolean hasHostname();
    public A withNewHostname(String arg1);
    public A withNewHostname(StringBuilder arg1);
    public A withNewHostname(StringBuffer arg1);
    public A addToOrganizations(int index,String item);
    public A setToOrganizations(int index,String item);
    public A addToOrganizations(String... items);
    public A addAllToOrganizations(Collection<String> items);
    public A removeFromOrganizations(String... items);
    public A removeAllFromOrganizations(Collection<String> items);
    public List<String> getOrganizations();
    public String getOrganization(int index);
    public String getFirstOrganization();
    public String getLastOrganization();
    public String getMatchingOrganization(Predicate<String> predicate);
    public Boolean hasMatchingOrganization(Predicate<String> predicate);
    public A withOrganizations(List<String> organizations);
    public A withOrganizations(String... organizations);
    public Boolean hasOrganizations();
    public A addNewOrganization(String arg1);
    public A addNewOrganization(StringBuilder arg1);
    public A addNewOrganization(StringBuffer arg1);
    public A addToTeams(int index,String item);
    public A setToTeams(int index,String item);
    public A addToTeams(String... items);
    public A addAllToTeams(Collection<String> items);
    public A removeFromTeams(String... items);
    public A removeAllFromTeams(Collection<String> items);
    public List<String> getTeams();
    public String getTeam(int index);
    public String getFirstTeam();
    public String getLastTeam();
    public String getMatchingTeam(Predicate<String> predicate);
    public Boolean hasMatchingTeam(Predicate<String> predicate);
    public A withTeams(List<String> teams);
    public A withTeams(String... teams);
    public Boolean hasTeams();
    public A addNewTeam(String arg1);
    public A addNewTeam(StringBuilder arg1);
    public A addNewTeam(StringBuffer arg1);
    public interface CaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConfigMapNameReferenceFluent<GitHubIdentityProviderFluent.CaNested<N>> {

        public N and();
        public N endCa();    }


    public interface ClientSecretNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SecretNameReferenceFluent<GitHubIdentityProviderFluent.ClientSecretNested<N>> {

        public N and();
        public N endClientSecret();    }


}
